/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2014 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* System Name  : RZ/T1 Init program
* File Name    : init_main.c
* Version      : 1.0
* Device       : R7S9100xx
* Abstract     : Main program for RZ/T1 Init program
* Tool-Chain   : IAR Embedded Workbench Ver.8.32.1
* OS           : not use
* H/W Platform : T6215 RZ/T1 board
* Description  : Initialize the peripheral settings of RZ/T1
* Limitation   : none
*******************************************************************************/
/*******************************************************************************
* History      : DD.MM.YYYY Version  Description
*              :                     First Release
*******************************************************************************/

/*******************************************************************************
Includes <System Includes> , "Project Includes"
*******************************************************************************/
#include <stdint.h>
#include "iodefine.h"
#include "r_system.h"
#include "r_icu_init.h"
#include "r_mpc.h"
#include "r_port.h"
#include "r_ecm.h"
#include <math.h>
#include "..\ICS_RZT1\ICS2_RZT1.h"


/*******************************************************************************
Macro definitions
*******************************************************************************/

/*******************************************************************************
Typedef definitions
*******************************************************************************/


/*******************************************************************************
Imported global variables and functions (from other files)
*******************************************************************************/
extern void R_IRQ9_isr(void);
extern void R_IRQ16_isr(void);

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/


/*******************************************************************************
Private variables and functions
*******************************************************************************/
int main(void);
void port_init(void);
void ecm_init(void);
void icu_init(void);
void soft_wait(void);

#define  TWOPI    (2.0f*3.1415926535f)

float   wt   = 0.0f;
float   dwt  = TWOPI*50.0f/10000.0f;
float   refu = 0.0f;
float   refv = 0.0f;
float   refw = 0.0f;
float   m    = 1.0f;
float   dm   = 0.0001f;
int32_t up    = 0;
float   f_mx = 0;
float   f_x  = 0;

/*******************************************************************************
* Outline      : main processing
* Function Name: main
* Description  : Initialize the peripheral settings of RZ/T1.
                 Main processing is toggle output of PF7 (LED0). 
* Arguments    : none
* Return Value : none
*******************************************************************************/
int main (void)
{
    /* Initialize the port function */
    port_init();
    
    /* Initialize the ECM function */
    ecm_init();
    
    /* Initialize the ICU settings */
    icu_init();  
    
    /* Initialize the ICS setting  */
  //ics2_init(ICS_SCI0_P40_P24, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  // Custom       OK
  //ics2_init(ICS_SCI0_P40_P42, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  //        T6215 OK
  //ics2_init(ICS_SCI0_P40_P24, 4, 18, 1);  // speed=18, 0.9868Mbps, 7.9MHz // Custom       OK
  //ics2_init(ICS_SCI1_PE5_PE6, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  // Custom       OK
  //ics2_init(ICS_SCI1_P72_P73, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  //        T6215(OK) R38,R41
    ics2_init(ICS_SCI2_PS7_PS6, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  // Custom/T6215 OKOK
  //ics2_init(ICS_SCI2_P91_P92, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  // Custom(SP)   OK
  //ics2_init(ICS_SCI2_PA5_PA4, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  //        T6215 OK
  //ics2_init(ICS_SCI3_PU3_PU2, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  // Custom       OK
  //ics2_init(ICS_SCI4_PM0_PU7, 4,  2, 1);  // speed=2,  6.25Mbps,   50MHz  // Custom       OK

     
    while (1)
    {
        int32_t i;
        
        wt = wt + dwt;
        if (wt>TWOPI) { wt = wt - TWOPI; }
        
        if (up==1)
        {
             m = m + dm;
             if (m>=1.0f) { up = 0; }
        }
        else
        {
             m = m - dm;
             if (m<=0.5f) { up = 1; }
        }

        refu  = m * sinf(wt);
        refv  = m * sinf(wt-TWOPI*1.0f/3.0f);
        refw  = m * sinf(wt-TWOPI*2.0f/3.0f);
        f_mx  = f_x * m;
      
        ics2_watchpoint();
        
        for (i=0;i<5000;i++)
        {
            asm("nop");  
        }
    }
   
}
/*******************************************************************************
 End of function main
*******************************************************************************/

/*******************************************************************************
* Function Name: port_init
* Description  : Initialize port setting as following.
*                 PF7 : Output and low level.
*                 P56 : Output and low level.
* Arguments    : none
* Return Value : none
*******************************************************************************/
void port_init(void)
{
#if 0
      /* Set PF7 to Output port pin (Using LED0) */
      PORTF.PDR.BIT.B7 = PORT_DIRECTION_HIZ;  // Initialize port settings
      PORTF.PMR.BIT.B7 = PORT_MODE_GENERAL;
  
      PORTF.PODR.BIT.B7 = PORT_OUTPUT_LOW;  // Set output level to Low
      PORTF.PDR.BIT.B7 = PORT_DIRECTION_OUTPUT;  // Set port direction to output
    
    /* Set P56 to Output port pin (Using LED1) */
     PORT5.PDR.BIT.B6 = PORT_DIRECTION_HIZ;  // Initialize port settings
     PORT5.PMR.BIT.B6 = PORT_MODE_GENERAL;
  
     PORT5.PODR.BIT.B6 = PORT_OUTPUT_LOW;  // Set output level to Low
     PORT5.PDR.BIT.B6 = PORT_DIRECTION_OUTPUT;  // Set port direction to output
#endif
    
    //for RZ/T1 CPU board
#if 0
    /* Set PL3 to Output port pin (Using LED1) */
    PORTL.PDR.BIT.B3 = PORT_DIRECTION_HIZ;  // Initialize port settings
    PORTL.PMR.BIT.B3 = PORT_MODE_GENERAL;
  
    PORTL.PODR.BIT.B3 = PORT_OUTPUT_LOW;  // Set output level to Low
    PORTL.PDR.BIT.B3 = PORT_DIRECTION_OUTPUT;  // Set port direction to output
    
    /* Set PL1 to Output port pin (Using LED2) */
    PORTL.PDR.BIT.B1 = PORT_DIRECTION_HIZ;  // Initialize port settings
    PORTL.PMR.BIT.B1 = PORT_MODE_GENERAL;
  
    PORTL.PODR.BIT.B1 = PORT_OUTPUT_LOW;  // Set output level to Low
    PORTL.PDR.BIT.B1 = PORT_DIRECTION_OUTPUT;  // Set port direction to output
#endif
}

/*******************************************************************************
 End of function port_init
*******************************************************************************/

/*******************************************************************************
* Function Name: ecm_init
* Description  : Initialize ECM setting as following.
*                  Error 35 : Permit to generate the ECM reset                                
* Arguments    : none
* Return Value : none
*******************************************************************************/
void ecm_init(void)
{
    volatile uint8_t result;
    
    /* Initialize ECM function  */
    R_ECM_Init();
    
}

/*******************************************************************************
 End of function ecm_init
*******************************************************************************/

/*******************************************************************************
* Function Name: icu_init
* Description  : Initialize Interrupt Controller Unit setting.
* Arguments    : none
* Return Value : none
*******************************************************************************/
void icu_init(void)
{
    /*******************************************/
    /*      Set IRQ pin interrupt 5(IRQ9)      */
    /*******************************************/

    R_ICU_Disable( ICU_VEC_NUM_9 );  // Mask IRQ9
    
    /* Set external interrupt pin: pin number, Falling edge, 
    degital noise filter(PCLKB/1) (if IRQ pin is used)  */
 
    R_ICU_ExtPinInit( ICU_EXT_PIN_5, ICU_DETECT_FALL, ICU_DNF_DIVISION_64 );
    
    /* Set multi-function pin controller setting (if IRQ pin is used) */    
    PORTN.PDR.BIT.B5 = PORT_DIRECTION_HIZ;  // Initialize port settings
    PORTN.PMR.BIT.B5 = PORT_MODE_GENERAL;
    
    R_MPC_WriteEnable();  // Enables writing to the PFS register 
    MPC.PN5PFS.BIT.ISEL = MPC_IRQ_ENABLE ;  // Set PN5PFS.ISEL bit to 1.
    R_MPC_WriteDisable();  // Disables writing to the PFS register
    
    /* Set VIC setting: vector number, detection type, priority level */
    /* Casting the ISR to a (uint32_t) is valid because this ISR will
    be located in 32 bit memory map address */
    R_ICU_Regist( ICU_VEC_NUM_9, ICU_TYPE_EDGE, ICU_PRIORITY_15, (uint32_t) R_IRQ9_isr );
    
    R_ICU_Enable( ICU_VEC_NUM_9 );  // Enable IRQ9
 
    /* Enable IRQ interrupt (Clear CPSR.I bit to 0) */
    asm("cpsie i");   // Clear CPSR.I bit to 0 
    asm("isb");       // Ensuring Context-changing
    
}

/*******************************************************************************
 End of function icu_init
*******************************************************************************/


/* End of File */


